@@ -22,16 +22,18 @@
 #include "../krdb/krdb.h"
 #include "config-kcm.h"
 #include "config-workspace.h"
-#include <klauncher_iface.h>
 
 #include <KAboutData>
 #include <KSharedConfig>
 #include <KGlobalSettings>
 #include <KIconLoader>
+#include <KIO/ApplicationLauncherJob>
 #include <KAutostart>
-#include <KRun>
+#include <KDialogJobUiDelegate>
 #include <KService>
 
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QDebug>
 #include <QQuickItem>
 #include <QQuickWindow>
@@ -47,6 +49,8 @@
 
 #include <X11/Xlib.h>
 
+#include <updatelaunchenvjob.h>
+
 #include "lookandfeelsettings.h"
 
 #ifdef HAVE_XCURSOR
@@ -121,7 +125,7 @@ QStandardItemModel *KCMLookandFeel::lookAndFeelModel() const
 
 int KCMLookandFeel::pluginIndex(const QString &pluginName) const
 {
-    const auto results = m_model->match(m_model->index(0, 0), PluginNameRole, pluginName, 1, Qt::MatchExactly);
+    const auto results = m_model->match(m_model->index(0, 0), PluginNameRole, pluginName);
     if (results.count() == 1) {
         return results.first().row();
     }
@@ -385,12 +389,14 @@ void KCMLookandFeel::save()
                 const QStringList autostartServices = cg.readEntry("Services", QStringList());
 
                 for (const QString &serviceFile : autostartServices) {
-                    KService service(serviceFile + QStringLiteral(".desktop"));
+                    KService::Ptr service{new KService(serviceFile + QStringLiteral(".desktop"))};
                     KAutostart as(serviceFile);
-                    as.setCommand(service.exec());
+                    as.setCommand(service->exec());
                     as.setAutostarts(true);
                     if (qEnvironmentVariableIsSet("KDE_FULL_SESSION")) {
-                        KRun::runApplication(service, {}, nullptr);
+                        auto *job = new KIO::ApplicationLauncherJob(service);
+                        job->setUiDelegate(new KDialogJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, nullptr));
+                        job->start();
                     }
                 }
             }
@@ -490,7 +496,7 @@ void KCMLookandFeel::setCursorTheme(const QString themeName)
     // in previous versions the Xfixes code wasn't enabled due to a bug in the
     // build system (freedesktop bug #975).
 #if defined(HAVE_XFIXES) && XFIXES_MAJOR >= 2 && XCURSOR_LIB_VERSION >= 10105
-    const int cursorSize = cg.readEntry("cursorSize", 0);
+    const int cursorSize = cg.readEntry("cursorSize", 24);
 
     QDir themeDir = cursorThemeDir(themeName, 0);
 
@@ -504,11 +510,7 @@ void KCMLookandFeel::setCursorTheme(const QString themeName)
         return;
     }
 
-    // Set up the proper launch environment for newly started apps
-    OrgKdeKLauncherInterface klauncher(QStringLiteral("org.kde.klauncher5"),
-                                       QStringLiteral("/KLauncher"),
-                                       QDBusConnection::sessionBus());
-    klauncher.setLaunchEnv(QStringLiteral("XCURSOR_THEME"), themeName);
+    UpdateLaunchEnvJob launchEnvJob(QStringLiteral("XCURSOR_THEME"), themeName);
 
     // Update the Xcursor X resources
     runRdb(0);
